==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/security/kotlin/outputs/TimeWindowCustomAlertRuleResponse.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.security.kotlin.outputs

import kotlin.Boolean
import kotlin.Int
import kotlin.String
import kotlin.Suppress

/**
 * A custom alert rule that checks if the number of activities (depends on the custom alert type) in a time window is within the given range.
 * @property description The description of the custom alert.
 * @property displayName The display name of the custom alert.
 * @property isEnabled Status of the custom alert.
 * @property maxThreshold The maximum threshold.
 * @property minThreshold The minimum threshold.
 * @property ruleType The type of the custom alert rule.
 * Expected value is 'TimeWindowCustomAlertRule'.
 * @property timeWindowSize The time window size in iso8601 format.
 */
public data class TimeWindowCustomAlertRuleResponse(
    public val description: String,
    public val displayName: String,
    public val isEnabled: Boolean,
    public val maxThreshold: Int,
    public val minThreshold: Int,
    public val ruleType: String,
    public val timeWindowSize: String,
) {
    public companion object {
        public
        fun toKotlin(javaType: com.pulumi.azurenative.security.outputs.TimeWindowCustomAlertRuleResponse):
            TimeWindowCustomAlertRuleResponse = TimeWindowCustomAlertRuleResponse(
            description = javaType.description(),
            displayName = javaType.displayName(),
            isEnabled = javaType.isEnabled(),
            maxThreshold = javaType.maxThreshold(),
            minThreshold = javaType.minThreshold(),
            ruleType = javaType.ruleType(),
            timeWindowSize = javaType.timeWindowSize(),
        )
    }
}

==> pulumi-azure-native-kotlin-2.44.1.0-sources.jar: com/pulumi/azurenative/security/kotlin/outputs/TimeWindowCustomAlertRuleResponse.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.security.kotlin.outputs

import kotlin.Boolean
import kotlin.Int
import kotlin.String
import kotlin.Suppress

/**
 * A custom alert rule that checks if the number of activities (depends on the custom alert type) in a time window is within the given range.
 * @property description The description of the custom alert.
 * @property displayName The display name of the custom alert.
 * @property isEnabled Status of the custom alert.
 * @property maxThreshold The maximum threshold.
 * @property minThreshold The minimum threshold.
 * @property ruleType The type of the custom alert rule.
 * Expected value is 'TimeWindowCustomAlertRule'.
 * @property timeWindowSize The time window size in iso8601 format.
 */
public data class TimeWindowCustomAlertRuleResponse(
    public val description: String,
    public val displayName: String,
    public val isEnabled: Boolean,
    public val maxThreshold: Int,
    public val minThreshold: Int,
    public val ruleType: String,
    public val timeWindowSize: String,
) {
    public companion object {
        public fun toKotlin(javaType: com.pulumi.azurenative.security.outputs.TimeWindowCustomAlertRuleResponse): TimeWindowCustomAlertRuleResponse = TimeWindowCustomAlertRuleResponse(
            description = javaType.description(),
            displayName = javaType.displayName(),
            isEnabled = javaType.isEnabled(),
            maxThreshold = javaType.maxThreshold(),
            minThreshold = javaType.minThreshold(),
            ruleType = javaType.ruleType(),
            timeWindowSize = javaType.timeWindowSize(),
        )
    }
}
